# Efficient Visual Pretraining with Contrastive Detection

Implementation of "Efficient Visual Pretraining with Contrastive Detection" model from https://arxiv.org/pdf/2103.10957.pdf.
All models are trainable in PyTorch.

## Install

```bash
pip3 install pytorch_eff_vis_pretraining
```

## Use

```python
from pytorch_eff_vis_pretraining import ResNet50, ResNet200

resnet50 = ResNet50()
resnet200 = ResNet200()
```
